@@ -22,10 +22,10 @@ class Domain(models.Model):
 
     def get_uptime(self):
         up_count = CheckLog.objects.filter(atc__domain=self, status=True).count()
-        down_count = CheckLog.objects.filter(atc__domain=self, status=False).count()
+        all_count = CheckLog.objects.filter(atc__domain=self).count()
         if up_count == 0:
             return 0
-        return 100.0 - 100.0 * float(down_count) / float(up_count)
+        return 100.0 * float(up_count) / float(all_count)
 
     def is_up(self):
         try:
