@@ -2,5 +2,5 @@
 from django.conf.urls import patterns, url
 
 urlpatterns = patterns(
-    'statistic.views',
+    'pingokio.statistic.views',
     url(r'^all_time/$', 'all_time', name='statitstic_all_time'))
